# googletrends

[![Python](https://img.shields.io/pypi/pyversions/googletrends)](https://img.shields.io/pypi/pyversions/googletrends)
[![PyPI Version](https://img.shields.io/pypi/v/googletrends)](https://pypi.org/project/googletrends/)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/erdogant/googletrends/blob/master/LICENSE)
[![Github Forks](https://img.shields.io/github/forks/erdogant/googletrends.svg)](https://github.com/erdogant/googletrends/network)
[![GitHub Open Issues](https://img.shields.io/github/issues/erdogant/googletrends.svg)](https://github.com/erdogant/googletrends/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![Downloads](https://pepy.tech/badge/googletrends/month)](https://pepy.tech/project/googletrends/month)
[![Downloads](https://pepy.tech/badge/googletrends)](https://pepy.tech/project/googletrends)
[![BuyMeCoffee](https://img.shields.io/badge/buymea-coffee-yellow.svg)](https://www.buymeacoffee.com/erdogant)
[![Sphinx](https://img.shields.io/badge/Sphinx-Docs-Green)](https://erdogant.github.io/googletrends/)
<!---[![Coffee](https://img.shields.io/badge/coffee-black-grey.svg)](https://erdogant.github.io/donate/?currency=USD&amount=5)-->

``googletrends`` is Python package to examine trending, spatio and temporal google searching for input queries.
Data is al arround us. Some data is easy to get, others are not. Especially when it comes to what people are "thinking" related to an issue/brand/company can be though. However, the "thinking" process can supported by googling about the subject. So if we know what people are searching for, it can give insights in the "common" thoughts. To make it a bit less creepy, lets not do this on an individual basis. I developed the python package googletrends that allows to easily examine the search results per country/region and/or per time-frame and with(out) a specific keyword.
To demonstrate this, lets examine the google searches for the keywords "Corona" and "Virus", "covid-19" in the Netherlands, Italy, Belgium and Germany starting from December 2019 up to today. If you want to examine other keywords/countries/time frames, simply pip install the library.

<p align="center">
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/summary.png" width="1000" />
</p>


# 
**⭐️ Star this repo if you like it ⭐️**
#

#### Install googletrends from PyPI

```bash
pip install googletrends
```

#### Import googletrends package

```python
import googletrends
```
# 


### [Documentation pages](https://erdogant.github.io/googletrends/)

On the [documentation pages](https://erdogant.github.io/googletrends/) you can find detailed information about the working of the ``googletrends`` with many examples. 

<hr> 

### Examples

# 

* [Example: Get country names and abbrevations](https://erdogant.github.io/googletrends/pages/html/Examples.html#)

# 

* [Example: Examine google searches over time ](https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-timewise)

<p align="left">
  <a href="https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-timewise">
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/bitcoin_temporal.png" width="600" />
  </a>
</p>


# 

* [Example: Examine google searches over time groupby](https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-timewise)

<p align="left">
  <a href="https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-timewise">
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/bitcoin_temporal2.png" width="600" />
  </a>
</p>

# 

* [Example: Examine google searches over geographical locations.](https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-geographical)

<p align="left">
  <a href="https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-geographical">
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/spatio_NL.png" width="600" />
    <br>
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/bitcoin_geo_NL.png" width="600" />
    <br>
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/bitcoin_geo_worldmap.png" width="600" />
  </a>
</p>

# 

* [Example: Examine trending searches](https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-trends)

<p align="left">
  <a href="https://erdogant.github.io/googletrends/pages/html/Examples.html#analyze-trends">
  <img src="https://github.com/erdogant/googletrends/blob/master/docs/figs/bitcoin_NL_trends.png" width="600" />
  </a>
</p>



### References
* http://www.w3.org/Consortium/Legal/copyright-software

### Maintainers
* Erdogan Taskesen, github: [erdogant](https://github.com/erdogant)

### Contribute
* All kinds of contributions are welcome!
* If you wish to buy me a <a href="https://www.buymeacoffee.com/erdogant">Coffee</a> for this work, it is very appreciated :)


